# Pangolin
Pangolin is a graphical image segmentation/annotation tool written in Python using Qt. 
Currently a WIP project.
TODO:
- Move drawing commands into item classes

![Screenshot 1](screenshots/sc1.png?raw=true "Screenshot 1")

## Installation

## Usage

## License
